@@ -62,9 +62,9 @@ c                  decay in Epics).
                else   
                   call cdecayWEL(p, g, x)
                   length =(1.0d0 -  x/g)/a
-                  if(length .le. 0.) then
-c                       many happpen when a<<<1.
-                     length = 1.d-3
+                  if(length .lt. 0.) then
+c                       may happpen when a <<< 1.
+                     length = 0.d0
                   endif
                endif
             endif
@@ -137,6 +137,12 @@ c           integral of 1/sqrt(2(x-1)) from 1 to xm
        int1 = sqrt(2.0*(xm-1.0))
 c           integral of (2x)**p/x from (1 to xm)
        int2 = 2.0**p/p *(xm**p-1.0)
+c              xm**p = 1.0
+       if(int1 .eq. 0. .and. int2 .eq. 0.) then
+          x = 1.0
+          return  ! **********
+       endif
+
        do while (.true.)
 c
           call rndc(u)
