@@ -19,9 +19,11 @@ c          this is called after primary is fixed.
       real*8 clenbetween2h, cnewcos
       character*80 tracefile
       record /track/ incident
+      record /coord / xyz
+      integer i
       data zAngleSave/-1.d30/
       save zAngleSave
-
+      
 
       Zfirst.pos.depth = 0.
       Zsave = -1.d30
@@ -61,6 +63,18 @@ c
          call csetObsZ(cxyz2det)
       elseif(abs(ObsPlane) .eq. perpendicular ) then
          call csetObsZ(cxyz2prim)
+c          inicident.where can be fixed here. not  in cmkIncidnt
+         call cxyz2prim(ObsSites(NoOfSites).pos.xyz, 
+     *                  incident.pos.xyz, xyz)         
+         do i = 1, NoOfSites
+            if(xyz.r(3) .gt. ObsSites(i).zpl ) then
+               incident.where = i
+               goto 222
+            endif
+         enddo
+         incident.where = NoOfSites + 1
+         IncidentCopy.where = incident.where
+ 222     continue
       elseif(ObsPlane .eq.  notUsed ) then
 c           Nothing to do. observation is at height =
 c           BorderHeighL. (for neutrino)
